@@ -1,18 +1,20 @@
 from ail_typo_squatting.typo import runAll
 
 from ail_typo_squatting.typo import formatOutput
+from ail_typo_squatting.typo import dnsResolving
 
-from ail_typo_squatting.typo import characterOmission
+from ail_typo_squatting.typo import omission
 from ail_typo_squatting.typo import repetition
+from ail_typo_squatting.typo import changeOrder
 from ail_typo_squatting.typo import transposition
 from ail_typo_squatting.typo import replacement
 from ail_typo_squatting.typo import doubleReplacement
-from ail_typo_squatting.typo import insertion
+from ail_typo_squatting.typo import keyboardInsertion
 from ail_typo_squatting.typo import addition
 from ail_typo_squatting.typo import missingDot
 from ail_typo_squatting.typo import stripDash
-from ail_typo_squatting.typo import vowel_swap
-from ail_typo_squatting.typo import hyphenation
+from ail_typo_squatting.typo import vowelSwap
+from ail_typo_squatting.typo import addDash
 from ail_typo_squatting.typo import bitsquatting
 from ail_typo_squatting.typo import homoglyph
 from ail_typo_squatting.typo import commonMisspelling
@@ -21,3 +23,5 @@ from ail_typo_squatting.typo import wrongTld
 from ail_typo_squatting.typo import addTld
 from ail_typo_squatting.typo import subdomain
 from ail_typo_squatting.typo import singularPluralize
+from ail_typo_squatting.typo import changeDotDash
+
